package mobvista.dmp.datasource.id_mapping

import mobvista.dmp.common.MobvistaConstant
import mobvista.dmp.datasource.adn.AdnConstant
import org.apache.commons.lang3.StringUtils
import org.apache.spark.rdd.RDD
import org.apache.spark.sql.{Row, SparkSession}

/**
 * @package: mobvista.dmp.datasource.id_mapping
 * @author: wangjf
 * @date: 2021/11/30
 * @time: 7:51 下午
 * @email: jinfeng.wang@mobvista.com
 */
class AdnRequest extends EtlDeviceIdDaily {

  override def processData(date: String, spark: SparkSession): RDD[(String, Row)] = {
    spark.udf.register("getDevId", AdnConstant.getDevId _)
    //  DWD
    //  val sql = Constant.adn_request_sql.replace("@date", date)
    //  ODS
    val sql = Constant.adn_request_sql_v2.replace("@date", date)
    val rdd = spark.sql(sql).coalesce(60000).rdd.map(row => {
      val gaid = row.getAs[String]("gaid")
      val idfa = row.getAs[String]("idfa")
      val imei = row.getAs[String]("imei")
      val androidId = row.getAs[String]("androidid")
      val extSysid = row.getAs[String]("extsysid")
      val platform = row.getAs[String]("platform").toLowerCase
      val oaid = row.getAs[String]("oaid")
      val idfv = row.getAs[String]("idfv")
      val country = row.getAs[String]("country")
      val arr = extSysid.split(",", -1)
      val sysId = if (StringUtils.isNotBlank(arr(0)) &&
        arr(0).matches(MobvistaConstant.didPtn) &&
        !arr(0).matches(MobvistaConstant.allZero)) {
        arr(0)
      } else {
        ""
      }

      val bkupId = if (arr.length == 2 && StringUtils.isNotBlank(arr(1)) &&
        arr(1).matches(MobvistaConstant.didPtn) &&
        !arr(1).matches(MobvistaConstant.allZero)) {
        arr(1)
      } else {
        ""
      }

      val rw = if ("ios".equalsIgnoreCase(platform)) {
        Row(idfa, idfv, sysId, bkupId, "", "", country)
      } else {
        Row(imei, androidId, oaid, gaid, sysId, bkupId, "", "", country)
      }
      (platform, rw)
    })
    rdd
  }
}

object AdnRequest {
  def main(args: Array[String]): Unit = {
    new AdnRequest().run(args)
  }
}