package mobvista.dmp.datasource.id_mapping

import mobvista.dmp.common.MobvistaConstant
import org.apache.commons.lang3.StringUtils
import org.apache.spark.rdd.RDD
import org.apache.spark.sql.{Row, SparkSession}

/**
 * @package: mobvista.dmp.datasource.id_mapping
 * @author: wangjf
 * @date: 2021/11/30
 * @time: 7:51 下午
 * @email: jinfeng.wang@mobvista.com
 */
class DspReq extends EtlDeviceIdDaily {

  override def processData(date: String, spark: SparkSession): RDD[(String, Row)] = {
    //  DWD
    //  val sql = Constant.dsp_req_sql.replace("@date", date)
    //  ODS
    val sql = Constant.dsp_req_sql_v2.replace("@date", date)
    val rdd = spark.sql(sql).coalesce(60000).rdd.map(row => {
      var idfa = row.getAs[String]("idfa")
      var gaid = row.getAs[String]("gaid")
      val platform = row.getAs[String]("platform")
      val exitId = row.getAs[String]("exitid")
      val country = row.getAs[String]("country").toUpperCase()
      var idfv = ""
      var oaid = ""
      var imei = ""
      var androidId = ""
      if (StringUtils.isNotBlank(exitId)) {
        val devIds = splitFun(exitId, ",")
        if (devIds.length >= 17) {
          if ("ios".equalsIgnoreCase(platform)) {
            if (StringUtils.isBlank(idfa) && StringUtils.isNotBlank(devIds(1)) && devIds(1).matches(MobvistaConstant.didPtn)) {
              idfa = devIds(1)
            }
            if (StringUtils.isNotBlank(devIds(16)) && devIds(16).matches(MobvistaConstant.didPtn)) {
              idfv = devIds(16)
            }
          } else {
            if (StringUtils.isBlank(gaid) && StringUtils.isNotBlank(devIds(0)) && devIds(0).matches(MobvistaConstant.didPtn)) {
              gaid = devIds(0)
            }
            if (StringUtils.isNotBlank(devIds(12))) {
              oaid = devIds(12)
            }
            if (StringUtils.isNotBlank(devIds(4)) && devIds(4).matches(MobvistaConstant.imeiPtn)) {
              imei = devIds(4)
            }
            if (StringUtils.isNotBlank(devIds(7)) && devIds(7).matches(MobvistaConstant.andriodIdPtn)) {
              androidId = devIds(7)
            }
          }
        }
      }
      val rw = if ("ios".equalsIgnoreCase(platform)) {
        Row(idfa, idfv, "", "", "", "", country)
      } else {
        Row(imei, androidId, oaid, gaid, "", "", "", "", country)
      }
      (platform, rw)
    })
    rdd
  }
}

object DspReq {
  def main(args: Array[String]): Unit = {
    new DspReq().run(args)
  }
}